import { BasePlugin, PluginConfig, ToolSettingsMap } from '../types/plugins';
/**
 * The plugin service provides a singleton to store all plugins injected into the application
 * and makes them available for all instances of `EditorJS`
 */
export declare class NgxEditorJSPluginService {
    /**
     * Object map of the plugin configurations
     */
    private pluginsMap;
    /**
     * When the class is initialized the initial plugins and any user plugins
     * will be passed in and merged and stored in the config map
     * @param initialPlugins Default plugins produced by the module
     * @param userPlugins User plugins injected into the application
     */
    constructor(initialPlugins: PluginConfig, userPlugins: PluginConfig);
    /**
     * Add a plugin to the store
     * @param key The key for the map to store the plugin
     * @param plugin The plugin instance to add to the service
     */
    add(key: string, plugin: BasePlugin): void;
    /**
     * Remove a plugin from the store
     * @param key
     */
    remove(key: string): void;
    /**
     * Get a single plugin from the map
     * @param name
     */
    get(key: string): BasePlugin;
    /**
     * Returns a map of all the plugins registered with this service
     */
    readonly plugins: PluginConfig;
    /**
     * Returns a map of tools to be initialized by the editor
     * @param exclude Optional array of keys to exclude from the map
     */
    getTools(exclude?: string[]): ToolSettingsMap;
}
